---
Summary: Write access to property on cards
Status: Ready
---

# Description

Goal is to allow setting property fields on cards from the command line
directly. This means you'll be able to go `sprop c1 assignee=lachlan` to set
the assignee of c1 to Lachlan.

For now - this will only work with property style fields.

# Cucumber

**GIVEN** a card
**WHEN** `sprop [card number] [key]=[value]` is run
**THEN** a property named by the key is set to the value in the card
